# sz-sdk-json-type-definition bin

The following files should have exactly the same content:

1. [sz-sdk-json-type-definition/bin/response-testcases.json](./response-testcases.json)
1. [sz-sdk-go/bin/response-testcases.json](https://github.com/senzing-garage/sz-sdk-go/blob/main/bin/response-testcases.json)
